/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.datastore.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * A (kind, ID/name) pair used to construct a key path.
 *
 * At most one of name or ID may be set. If either is set, the element is complete. If neither is
 * set, the element is incomplete.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Cloud Datastore API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class KeyPathElement extends GenericJson {

  /**
   * The ID of the entity. Always > 0.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long id;

  /**
   * The kind of the entity. Kinds matching regex "__.*__" are reserved/read-only. Cannot be "".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The name of the entity. Names matching regex "__.*__" are reserved/read-only. Cannot be "".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * The ID of the entity. Always > 0.
   * The value returned may be {@code null}.
   */
  public Long getId() {
    return id;
  }

  /**
   * The ID of the entity. Always > 0.
   * The value set may be {@code null}.
   */
  public KeyPathElement setId(Long id) {
    this.id = id;
    return this;
  }

  /**
   * The kind of the entity. Kinds matching regex "__.*__" are reserved/read-only. Cannot be "".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of the entity. Kinds matching regex "__.*__" are reserved/read-only. Cannot be "".
   * The value set may be {@code null}.
   */
  public KeyPathElement setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The name of the entity. Names matching regex "__.*__" are reserved/read-only. Cannot be "".
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The name of the entity. Names matching regex "__.*__" are reserved/read-only. Cannot be "".
   * The value set may be {@code null}.
   */
  public KeyPathElement setName(String name) {
    this.name = name;
    return this;
  }

}
