/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.datastore.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for Query.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Cloud Datastore API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Query extends GenericJson {

  /**
   * An ending point for the query results. Optional. Query cursors are returned in query result
   * batches.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String endCursor;

  /**
   * The filter to apply (optional).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Filter filter;

  /**
   * The properties to group by (if empty, no grouping is applied to the result set).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<PropertyReference> groupBy;

  static {
    // hack to force ProGuard to consider PropertyReference used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(PropertyReference.class);
  }

  /**
   * The kinds to query (if empty, returns entities from all kinds).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<KindExpression> kinds;

  static {
    // hack to force ProGuard to consider KindExpression used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(KindExpression.class);
  }

  /**
   * The maximum number of results to return. Applies after all other constraints. Optional.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer limit;

  /**
   * The number of results to skip. Applies before limit, but after all other constraints (optional,
   * defaults to 0).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer offset;

  /**
   * The order to apply to the query results (if empty, order is unspecified).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<PropertyOrder> order;

  static {
    // hack to force ProGuard to consider PropertyOrder used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(PropertyOrder.class);
  }

  /**
   * The projection to return. If not set the entire entity is returned.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<PropertyExpression> projection;

  static {
    // hack to force ProGuard to consider PropertyExpression used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(PropertyExpression.class);
  }

  /**
   * A starting point for the query results. Optional. Query cursors are returned in query result
   * batches.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String startCursor;

  /**
   * An ending point for the query results. Optional. Query cursors are returned in query result
   * batches.
   * The value returned may be {@code null}.
   */
  public String getEndCursor() {
    return endCursor;
  }

  /**
   * An ending point for the query results. Optional. Query cursors are returned in query result
   * batches.
   * The value set may be {@code null}.
   */
  public Query setEndCursor(String endCursor) {
    this.endCursor = endCursor;
    return this;
  }

  /**
   * The filter to apply (optional).
   * The value returned may be {@code null}.
   */
  public Filter getFilter() {
    return filter;
  }

  /**
   * The filter to apply (optional).
   * The value set may be {@code null}.
   */
  public Query setFilter(Filter filter) {
    this.filter = filter;
    return this;
  }

  /**
   * The properties to group by (if empty, no grouping is applied to the result set).
   * The value returned may be {@code null}.
   */
  public java.util.List<PropertyReference> getGroupBy() {
    return groupBy;
  }

  /**
   * The properties to group by (if empty, no grouping is applied to the result set).
   * The value set may be {@code null}.
   */
  public Query setGroupBy(java.util.List<PropertyReference> groupBy) {
    this.groupBy = groupBy;
    return this;
  }

  /**
   * The kinds to query (if empty, returns entities from all kinds).
   * The value returned may be {@code null}.
   */
  public java.util.List<KindExpression> getKinds() {
    return kinds;
  }

  /**
   * The kinds to query (if empty, returns entities from all kinds).
   * The value set may be {@code null}.
   */
  public Query setKinds(java.util.List<KindExpression> kinds) {
    this.kinds = kinds;
    return this;
  }

  /**
   * The maximum number of results to return. Applies after all other constraints. Optional.
   * The value returned may be {@code null}.
   */
  public Integer getLimit() {
    return limit;
  }

  /**
   * The maximum number of results to return. Applies after all other constraints. Optional.
   * The value set may be {@code null}.
   */
  public Query setLimit(Integer limit) {
    this.limit = limit;
    return this;
  }

  /**
   * The number of results to skip. Applies before limit, but after all other constraints (optional,
   * defaults to 0).
   * The value returned may be {@code null}.
   */
  public Integer getOffset() {
    return offset;
  }

  /**
   * The number of results to skip. Applies before limit, but after all other constraints (optional,
   * defaults to 0).
   * The value set may be {@code null}.
   */
  public Query setOffset(Integer offset) {
    this.offset = offset;
    return this;
  }

  /**
   * The order to apply to the query results (if empty, order is unspecified).
   * The value returned may be {@code null}.
   */
  public java.util.List<PropertyOrder> getOrder() {
    return order;
  }

  /**
   * The order to apply to the query results (if empty, order is unspecified).
   * The value set may be {@code null}.
   */
  public Query setOrder(java.util.List<PropertyOrder> order) {
    this.order = order;
    return this;
  }

  /**
   * The projection to return. If not set the entire entity is returned.
   * The value returned may be {@code null}.
   */
  public java.util.List<PropertyExpression> getProjection() {
    return projection;
  }

  /**
   * The projection to return. If not set the entire entity is returned.
   * The value set may be {@code null}.
   */
  public Query setProjection(java.util.List<PropertyExpression> projection) {
    this.projection = projection;
    return this;
  }

  /**
   * A starting point for the query results. Optional. Query cursors are returned in query result
   * batches.
   * The value returned may be {@code null}.
   */
  public String getStartCursor() {
    return startCursor;
  }

  /**
   * A starting point for the query results. Optional. Query cursors are returned in query result
   * batches.
   * The value set may be {@code null}.
   */
  public Query setStartCursor(String startCursor) {
    this.startCursor = startCursor;
    return this;
  }

}
